Page 132 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 132

Home

    were procommunist. These procommunist books all
    received favorable reviews and sold twenty times as
    many copies as the few anticommunist books. Among
    some of the leading magazines supporting Mao's
    Communists were: The Saturday Evening Post, Collier's
    Atlantic Monthly, and Harpers Companion.

    The combined weight of all the forces against Chiang
    Kai-shek was so great that to keep a free China alive he
    had to flee to the island of Taiwan with two million of his

    trees, one good and one evil.
    Under Mao, the Communists murdered | tens of

    millions of Chinese, waged war on religion, and brought
    China down to the level of the grinding poverty that is

    always the result of Socialism. :
    Under Chiang Kai-shek, Taiwan became a modern

    miracle of progress with a per capita income far
    exceeding that on the Communist mainland. On Taiwan,
    the Chinese people could enjoy representative

    the

    the Chinese people could enjoy representative
    government, and freedom of religion and expression on
    a level never before reached by the Chinese.

    On April 5, 1975, the day of a Chinese holiday when
    the Chinese honor the memory of their ancestors, Chiang
    Kai-shek left this world at 10 minutes to midnight. The

    could

    127

    Babylon's War Against God

    obtained control of the opinion molding media in the

    United States.

    This control was so effective that out of 29 books

    about China written between 1943 and 1944, 22 of these

    followers. The aftermath of the establishment of two

    Chinas then allowed the world to see the fruits of two

    representative